@@ -6,7 +6,7 @@
 
 #undef  bool
 
-#include <curses.h>
+#include <ncurses.h>
 
 #ifdef C_PANELSUPPORT
 #include <panel.h>
